# InvestOS

| | |
| --- | --- |
| Docs | [![website - investos.io](https://img.shields.io/badge/website-investos.io-black)](https://investos.io/) [![docs](https://img.shields.io/readthedocs/investos)](https://investos.readthedocs.io/en/latest/) |
| Package | [![PyPI - Version](https://img.shields.io/pypi/v/investos.svg?logo=pypi&label=PyPI&logoColor=gold)](https://pypi.python.org/pypi/investos) [![PyPI - Python Versions](https://img.shields.io/pypi/pyversions/investos.svg?logo=python&label=Python&logoColor=gold)](https://pypi.org/project/investos/) |
| Meta | [![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/) [![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) [![code style - Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![license - CC-BY-NC-SA-4.0](https://img.shields.io/badge/license-CC--BY--NC--SA--4.0-blue)](https://spdx.org/licenses/CC-BY-NC-SA-4.0.html) |

**InvestOS** (/InvEst əʊˈes/) is a Python library for investors who want to focus on generating alpha. As it stands today, it provides reliable backtesting and portfolio optimization software for investors... but we have bigger ambitions!

As mentioned in our [first blog article](https://blog.investos.io/why-we-created-investos/):

> From the start, our goal has been to support all possible optimization strategies and backtesting requirements through flexible, extensible code, while prioritizing reliability and ease-of-use.
> Once we feel we’ve achieved that goal as it pertains to portfolio optimization and backtesting, we plan to begin productizing other (non-IP) parts of investors’ alpha-generation process.

For more information, visit [investos.io](https://investos.io).
